==> IceWarpServer-9.4.1_RHEL5.tar.gz: scripts/wizard/db_filesystem.sh <==
#!/bin/bash
#
# IceWarp Merak Mail Server
# (c) IceWarp Ltd. 2008
#
#       All rights reserved.
#
# http://www.icewarp.com
#
# file: db_filesystem.sh - wizard menu script
# version: 1.0
#

# include functions
if [ -z "$SCRIPTDIR" ]
    then
	echo "This wizard script requires to have \$SCRIPTDIR variable set."
	exit 1
fi

if [ -z "$FUNCTIONS_INCLUDED" ]
    then
	source ${SCRIPTDIR}/inc/functions.sh
fi

# Init variables

# Storage type
# 0 - Professional file system
# 1 - Standard file system
# 2 - ODBC

fnc_db_filesystem_accounts()
{
    good ""
    ask_with_confirmation "Switch accounts storage to file system?" "Y" "n"
    if [ $? -eq 1 ]
	then
	    good "Switching accounts storage to file system..."
	    run_cmd_log "${MERAKDIR}/tool" modify system C_System_Storage_Accounts_StorageMode 1
	    if [ $? -ne 0 ]
		then
		    bad "Error calling tool"
		    return 1
	    fi
	    good "Storage switched."
	else
	    warn "Storage was not switched."
	    return 0
    fi

    good ""
    ask_with_confirmation "Convert data from database to file system?" "Y" "n"
    if [ $? -ne 1 ]
	then
	    return 0
    fi

    good "Converting data from database to filesystem..."
    run_cmd_log "${MERAKDIR}/tool" set storage 0
    if [ $? -ne 0 ]
	then
	    bad "Error calling tool"
	    return 1
    fi
    good "Data converted."
    return 0
}

SCRIPT_NAME=`basename $0`
RES=0
case $SCRIPT_NAME in
    "db_filesystem_accounts")
	fnc_db_filesystem_accounts
	RES=$?
	;;
    *)
	echo "Script called for unknown operation: ${SCRIPT_NAME}"
	RES=1
	;;
esac

exit $RES

==> IceWarpServer-10.0.5_RHEL5.tar.gz: scripts/wizard/db_filesystem.sh <==
#!/bin/bash
#
# IceWarp Server
# (c) IceWarp Ltd. 2008, 2009
#
#       All rights reserved.
#
# http://www.icewarp.com
#
# file: db_filesystem.sh - wizard menu script
# version: 1.0
#

# include functions
if [ -z "$SCRIPTDIR" ]
    then
	echo "This wizard script requires to have \$SCRIPTDIR variable set."
	exit 1
fi

if [ -z "$FUNCTIONS_INCLUDED" ]
    then
	source "${SCRIPTDIR}/inc/functions.sh"
fi

# Init variables

# Storage type
# 0 - Professional file system
# 1 - Standard file system
# 2 - ODBC

fnc_db_filesystem_accounts()
{
    good ""
    ask_with_confirmation "Switch accounts storage to file system?" "Y" "n"
    if [ $? -eq 1 ]
	then
	    good "Switching accounts storage to file system..."
	    run_cmd_log "${INSTALLDIR}/tool.sh" modify system C_System_Storage_Accounts_StorageMode 1
	    if [ $? -ne 0 ]
		then
		    bad "Error calling tool"
		    return 1
	    fi
	    good "Storage switched."
	else
	    warn "Storage was not switched."
	    return 0
    fi

    good ""
    ask_with_confirmation "Convert data from database to file system?" "Y" "n"
    if [ $? -ne 1 ]
	then
	    return 0
    fi

    good "Converting data from database to filesystem..."
    run_cmd_log "${INSTALLDIR}/tool.sh" set storage 0
    if [ $? -ne 0 ]
	then
	    bad "Error calling tool"
	    return 1
    fi
    good "Data converted."
    return 0
}

SCRIPT_NAME=`basename $0`
RES=0
case $SCRIPT_NAME in
    "db_filesystem_accounts")
	fnc_db_filesystem_accounts
	RES=$?
	;;
    *)
	echo "Script called for unknown operation: ${SCRIPT_NAME}"
	RES=1
	;;
esac

exit $RES
